@@ -26,7 +26,7 @@ class Exporter:
         self._data_fetch_end = now
         self._end = now
 
-    def create_args_parser(self) -> argparse.ArgumentParser:
+    def create_args_parser(self, require_config: bool = True) -> argparse.ArgumentParser:
         """
         Create and return a parser for command-line options. The parser is already set to accept
         common, shared options ``--config``, ``--export``, ``--log-file`` and ``--verbose``.
@@ -36,7 +36,7 @@ class Exporter:
 
         args_parser.add_argument(
             "--config", "-c",
-            required=True,
+            required=require_config,
             metavar="FILE",
             help="Path to plugin's YAML config file."
         )
@@ -127,13 +127,17 @@ class Exporter:
         self.logger.addHandler(log_handler)
         self.logger_verbose = options.verbose
 
-        try:
-            with open(options.config) as f:
-                self.config = ruamel.yaml.YAML().load(f)
-        except Exception as exc:
-            self.logger.critical(f"Can not open phoebe config file '{options.config}' \n\t\t{exc}")
+        if self.options.config:
+            try:
+                with open(options.config) as f:
+                    self.config = ruamel.yaml.YAML().load(f)
+            except Exception as exc:
+                self.logger.critical(f"Can not open phoebe config file '{options.config}' \n\t\t{exc}")
 
-            sys.exit(1)
+                sys.exit(1)
+
+        else:
+            self.config = {}
 
         return options
 
